@@ -250,3 +250,19 @@ class Postgres_Handler:
         results = self.__run_query(sql_query, value_dict)
         
         return self.__format_results(results)
+
+    def search_for_columns_from_id(self, table_name, return_columns, id):
+        id_key = "ID"
+        values_dict = {id_key: id}
+        column_identifier = sql.SQL(',').join(return_columns)
+        table_Identifier = sql.Identifier(table_name)
+        
+        query = sql.SQL('SELECT {columns} from {table} WHERE "ID"={Id}').format(
+            columns = column_identifier,
+            table = table_Identifier,
+            Id = sql.Placeholder(id_key)
+        )
+        
+        return self.__run_query(query, values_dict)
+                
+                
